@@ -241,6 +241,8 @@ struct dwfl_arange
 
 extern void __libdwfl_module_free (Dwfl_Module *mod) internal_function;
 
+/* Find the main ELF file, update MOD->elferr and/or MOD->main.elf.  */
+extern void __libdwfl_getelf (Dwfl_Module *mod) internal_function;
 
 /* Process relocations in debugging sections in an ET_REL file.
    FILE must be opened with ELF_C_READ_MMAP_PRIVATE or ELF_C_READ,
